# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_logs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61ws/aws_logs.proto\x12\x14oak9.tython.aws.logs\x1a\x13shared/shared.proto\"\xa2\x01\n\x0b\x44\x65stination\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x64\x65stination_name\x18\x02 \x01(\t\x12\x1a\n\x12\x64\x65stination_policy\x18\x03 \x01(\t\x12\x10\n\x08role_arn\x18\x04 \x01(\t\x12\x12\n\ntarget_arn\x18\x05 \x01(\t\"\xa8\x02\n\x04Logs\x12\x36\n\x0b\x64\x65stination\x18\x01 \x03(\x0b\x32!.oak9.tython.aws.logs.Destination\x12\x31\n\tlog_group\x18\x02 \x03(\x0b\x32\x1e.oak9.tython.aws.logs.LogGroup\x12\x33\n\nlog_stream\x18\x03 \x03(\x0b\x32\x1f.oak9.tython.aws.logs.LogStream\x12\x39\n\rmetric_filter\x18\x04 \x03(\x0b\x32\".oak9.tython.aws.logs.MetricFilter\x12\x45\n\x13subscription_filter\x18\x05 \x03(\x0b\x32(.oak9.tython.aws.logs.SubscriptionFilter\"v\n\x08LogGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0elog_group_name\x18\x02 \x01(\t\x12\x19\n\x11retention_in_days\x18\x03 \x01(\x05\"u\n\tLogStream\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0elog_group_name\x18\x02 \x01(\t\x12\x17\n\x0flog_stream_name\x18\x03 \x01(\t\"\xb7\x01\n MetricFilterMetricTransformation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rdefault_value\x18\x02 \x01(\x01\x12\x13\n\x0bmetric_name\x18\x03 \x01(\t\x12\x18\n\x10metric_namespace\x18\x04 \x01(\t\x12\x14\n\x0cmetric_value\x18\x05 \x01(\t\"\xcf\x01\n\x0cMetricFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x66ilter_pattern\x18\x02 \x01(\t\x12\x16\n\x0elog_group_name\x18\x03 \x01(\t\x12V\n\x16metric_transformations\x18\x04 \x03(\x0b\x32\x36.oak9.tython.aws.logs.MetricFilterMetricTransformation\"\xa8\x01\n\x12SubscriptionFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x64\x65stination_arn\x18\x02 \x01(\t\x12\x16\n\x0e\x66ilter_pattern\x18\x03 \x01(\t\x12\x16\n\x0elog_group_name\x18\x04 \x01(\t\x12\x10\n\x08role_arn\x18\x05 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_logs_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DESTINATION._serialized_start=66
  _DESTINATION._serialized_end=228
  _LOGS._serialized_start=231
  _LOGS._serialized_end=527
  _LOGGROUP._serialized_start=529
  _LOGGROUP._serialized_end=647
  _LOGSTREAM._serialized_start=649
  _LOGSTREAM._serialized_end=766
  _METRICFILTERMETRICTRANSFORMATION._serialized_start=769
  _METRICFILTERMETRICTRANSFORMATION._serialized_end=952
  _METRICFILTER._serialized_start=955
  _METRICFILTER._serialized_end=1162
  _SUBSCRIPTIONFILTER._serialized_start=1165
  _SUBSCRIPTIONFILTER._serialized_end=1333
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CacheCluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AZ_MODE_FIELD_NUMBER: builtins.int
    AUTO_MINOR_VERSION_UPGRADE_FIELD_NUMBER: builtins.int
    CACHE_NODE_TYPE_FIELD_NUMBER: builtins.int
    CACHE_PARAMETER_GROUP_NAME_FIELD_NUMBER: builtins.int
    CACHE_SECURITY_GROUP_NAMES_FIELD_NUMBER: builtins.int
    CACHE_SUBNET_GROUP_NAME_FIELD_NUMBER: builtins.int
    CLUSTER_NAME_FIELD_NUMBER: builtins.int
    ENGINE_FIELD_NUMBER: builtins.int
    ENGINE_VERSION_FIELD_NUMBER: builtins.int
    NOTIFICATION_TOPIC_ARN_FIELD_NUMBER: builtins.int
    NUM_CACHE_NODES_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PREFERRED_AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    PREFERRED_AVAILABILITY_ZONES_FIELD_NUMBER: builtins.int
    PREFERRED_MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    SNAPSHOT_ARNS_FIELD_NUMBER: builtins.int
    SNAPSHOT_NAME_FIELD_NUMBER: builtins.int
    SNAPSHOT_RETENTION_LIMIT_FIELD_NUMBER: builtins.int
    SNAPSHOT_WINDOW_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VPC_SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    az_mode: builtins.str
    auto_minor_version_upgrade: builtins.bool
    cache_node_type: builtins.str
    cache_parameter_group_name: builtins.str
    @property
    def cache_security_group_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    cache_subnet_group_name: builtins.str
    cluster_name: builtins.str
    engine: builtins.str
    engine_version: builtins.str
    notification_topic_arn: builtins.str
    num_cache_nodes: builtins.int
    port: builtins.int
    preferred_availability_zone: builtins.str
    @property
    def preferred_availability_zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    preferred_maintenance_window: builtins.str
    @property
    def snapshot_arns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    snapshot_name: builtins.str
    snapshot_retention_limit: builtins.int
    snapshot_window: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def vpc_security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        az_mode: builtins.str = ...,
        auto_minor_version_upgrade: builtins.bool = ...,
        cache_node_type: builtins.str = ...,
        cache_parameter_group_name: builtins.str = ...,
        cache_security_group_names: collections.abc.Iterable[builtins.str] | None = ...,
        cache_subnet_group_name: builtins.str = ...,
        cluster_name: builtins.str = ...,
        engine: builtins.str = ...,
        engine_version: builtins.str = ...,
        notification_topic_arn: builtins.str = ...,
        num_cache_nodes: builtins.int = ...,
        port: builtins.int = ...,
        preferred_availability_zone: builtins.str = ...,
        preferred_availability_zones: collections.abc.Iterable[builtins.str] | None = ...,
        preferred_maintenance_window: builtins.str = ...,
        snapshot_arns: collections.abc.Iterable[builtins.str] | None = ...,
        snapshot_name: builtins.str = ...,
        snapshot_retention_limit: builtins.int = ...,
        snapshot_window: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        vpc_security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_minor_version_upgrade", b"auto_minor_version_upgrade", "az_mode", b"az_mode", "cache_node_type", b"cache_node_type", "cache_parameter_group_name", b"cache_parameter_group_name", "cache_security_group_names", b"cache_security_group_names", "cache_subnet_group_name", b"cache_subnet_group_name", "cluster_name", b"cluster_name", "engine", b"engine", "engine_version", b"engine_version", "notification_topic_arn", b"notification_topic_arn", "num_cache_nodes", b"num_cache_nodes", "port", b"port", "preferred_availability_zone", b"preferred_availability_zone", "preferred_availability_zones", b"preferred_availability_zones", "preferred_maintenance_window", b"preferred_maintenance_window", "resource_info", b"resource_info", "snapshot_arns", b"snapshot_arns", "snapshot_name", b"snapshot_name", "snapshot_retention_limit", b"snapshot_retention_limit", "snapshot_window", b"snapshot_window", "tags", b"tags", "vpc_security_group_ids", b"vpc_security_group_ids"]) -> None: ...

global___CacheCluster = CacheCluster

@typing_extensions.final
class ElastiCache_CacheCluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CACHE_CLUSTER_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_INGRESS_FIELD_NUMBER: builtins.int
    SUBNET_GROUP_FIELD_NUMBER: builtins.int
    @property
    def cache_cluster(self) -> global___CacheCluster: ...
    @property
    def security_group(self) -> global___SecurityGroup: ...
    @property
    def security_group_ingress(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SecurityGroupIngress]: ...
    @property
    def subnet_group(self) -> global___SubnetGroup: ...
    def __init__(
        self,
        *,
        cache_cluster: global___CacheCluster | None = ...,
        security_group: global___SecurityGroup | None = ...,
        security_group_ingress: collections.abc.Iterable[global___SecurityGroupIngress] | None = ...,
        subnet_group: global___SubnetGroup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cache_cluster", b"cache_cluster", "security_group", b"security_group", "subnet_group", b"subnet_group"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cache_cluster", b"cache_cluster", "security_group", b"security_group", "security_group_ingress", b"security_group_ingress", "subnet_group", b"subnet_group"]) -> None: ...

global___ElastiCache_CacheCluster = ElastiCache_CacheCluster

@typing_extensions.final
class SecurityGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "resource_info", b"resource_info"]) -> None: ...

global___SecurityGroup = SecurityGroup

@typing_extensions.final
class SecurityGroupIngress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CACHE_SECURITY_GROUP_NAME_FIELD_NUMBER: builtins.int
    E_C2_SECURITY_GROUP_NAME_FIELD_NUMBER: builtins.int
    E_C2_SECURITY_GROUP_OWNER_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cache_security_group_name: builtins.str
    e_c2_security_group_name: builtins.str
    e_c2_security_group_owner_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cache_security_group_name: builtins.str = ...,
        e_c2_security_group_name: builtins.str = ...,
        e_c2_security_group_owner_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cache_security_group_name", b"cache_security_group_name", "e_c2_security_group_name", b"e_c2_security_group_name", "e_c2_security_group_owner_id", b"e_c2_security_group_owner_id", "resource_info", b"resource_info"]) -> None: ...

global___SecurityGroupIngress = SecurityGroupIngress

@typing_extensions.final
class SubnetGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CACHE_SUBNET_GROUP_NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cache_subnet_group_name: builtins.str
    description: builtins.str
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cache_subnet_group_name: builtins.str = ...,
        description: builtins.str = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cache_subnet_group_name", b"cache_subnet_group_name", "description", b"description", "resource_info", b"resource_info", "subnet_ids", b"subnet_ids"]) -> None: ...

global___SubnetGroup = SubnetGroup



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_cloud_tasks_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_cloud_pb2 as gcp_dot_gcp__cloud__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'gcp/gcp_google_cloud_tasks_bundle.proto\x12)oak9.tython.gcp.google_cloud_tasks_bundle\x1a\x13shared/shared.proto\x1a\x13gcp/gcp_cloud.proto\"\xdc\x02\n\x10GoogleCloudTasks\x12\x41\n\x11\x63loud_tasks_queue\x18\x01 \x01(\x0b\x32&.oak9.tython.gcp.cloud.CloudTasksQueue\x12W\n\x1d\x63loud_tasks_queue_iam_binding\x18\x02 \x03(\x0b\x32\x30.oak9.tython.gcp.cloud.CloudTasksQueueIamBinding\x12U\n\x1c\x63loud_tasks_queue_iam_member\x18\x03 \x03(\x0b\x32/.oak9.tython.gcp.cloud.CloudTasksQueueIamMember\x12U\n\x1c\x63loud_tasks_queue_iam_policy\x18\x04 \x03(\x0b\x32/.oak9.tython.gcp.cloud.CloudTasksQueueIamPolicyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_cloud_tasks_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLECLOUDTASKS._serialized_start=129
  _GOOGLECLOUDTASKS._serialized_end=477
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_iam.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_iam.proto\x12\x13oak9.tython.aws.iam\x1a\x13shared/shared.proto\"w\n\tAccessKey\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06serial\x18\x02 \x01(\x05\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x11\n\tuser_name\x18\x04 \x01(\t\"\xeb\x01\n\x03IAM\x12)\n\x05group\x18\x01 \x03(\x0b\x32\x1a.oak9.tython.aws.iam.Group\x12:\n\x0emanaged_policy\x18\x02 \x03(\x0b\x32\".oak9.tython.aws.iam.ManagedPolicy\x12+\n\x06policy\x18\x03 \x03(\x0b\x32\x1b.oak9.tython.aws.iam.Policy\x12\'\n\x04role\x18\x04 \x03(\x0b\x32\x19.oak9.tython.aws.iam.Role\x12\'\n\x04user\x18\x05 \x03(\x0b\x32\x19.oak9.tython.aws.iam.User\"t\n\x0bGroupPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bpolicy_name\x18\x02 \x01(\t\x12\x17\n\x0fpolicy_document\x18\x03 \x01(\t\"\xb3\x01\n\x05Group\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\x1b\n\x13managed_policy_arns\x18\x03 \x03(\t\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\x32\n\x08policies\x18\x05 \x03(\x0b\x32 .oak9.tython.aws.iam.GroupPolicy\"\x86\x01\n\x0fInstanceProfile\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15instance_profile_name\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\r\n\x05roles\x18\x04 \x03(\t\"\xcf\x01\n\rManagedPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06groups\x18\x03 \x03(\t\x12\x1b\n\x13managed_policy_name\x18\x04 \x01(\t\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\r\n\x05roles\x18\x06 \x03(\t\x12\r\n\x05users\x18\x07 \x03(\t\x12\x17\n\x0fpolicy_document\x18\x08 \x01(\t\"\x9d\x01\n\x06Policy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06groups\x18\x02 \x03(\t\x12\x13\n\x0bpolicy_name\x18\x03 \x01(\t\x12\r\n\x05roles\x18\x04 \x03(\t\x12\r\n\x05users\x18\x05 \x03(\t\x12\x17\n\x0fpolicy_document\x18\x06 \x01(\t\"s\n\nRolePolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bpolicy_name\x18\x02 \x01(\t\x12\x17\n\x0fpolicy_document\x18\x03 \x01(\t\"\x86\x03\n\x04Role\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1b\n\x13managed_policy_arns\x18\x03 \x03(\t\x12\x1c\n\x14max_session_duration\x18\x04 \x01(\x05\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x1c\n\x14permissions_boundary\x18\x06 \x01(\t\x12\x31\n\x08policies\x18\x07 \x03(\x0b\x32\x1f.oak9.tython.aws.iam.RolePolicy\x12\x11\n\trole_name\x18\x08 \x01(\t\x12\x31\n\x04tags\x18\t \x03(\x0b\x32#.oak9.tython.aws.iam.Role.TagsEntry\x12#\n\x1b\x61ssume_role_policy_document\x18\n \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x92\x01\n\x11ServiceLinkedRole\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rcustom_suffix\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x18\n\x10\x61ws_service_name\x18\x04 \x01(\t\"~\n\x10UserLoginProfile\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x1f\n\x17password_reset_required\x18\x03 \x01(\x08\"s\n\nUserPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bpolicy_name\x18\x02 \x01(\t\x12\x17\n\x0fpolicy_document\x18\x03 \x01(\t\"\xfc\x02\n\x04User\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06groups\x18\x02 \x03(\t\x12<\n\rlogin_profile\x18\x03 \x01(\x0b\x32%.oak9.tython.aws.iam.UserLoginProfile\x12\x1b\n\x13managed_policy_arns\x18\x04 \x03(\t\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x1c\n\x14permissions_boundary\x18\x06 \x01(\t\x12\x31\n\x08policies\x18\x07 \x03(\x0b\x32\x1f.oak9.tython.aws.iam.UserPolicy\x12\x31\n\x04tags\x18\x08 \x03(\x0b\x32#.oak9.tython.aws.iam.User.TagsEntry\x12\x11\n\tuser_name\x18\t \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"q\n\x13UserToGroupAddition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\r\n\x05users\x18\x03 \x03(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_iam_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ROLE_TAGSENTRY._options = None
  _ROLE_TAGSENTRY._serialized_options = b'8\001'
  _USER_TAGSENTRY._options = None
  _USER_TAGSENTRY._serialized_options = b'8\001'
  _ACCESSKEY._serialized_start=63
  _ACCESSKEY._serialized_end=182
  _IAM._serialized_start=185
  _IAM._serialized_end=420
  _GROUPPOLICY._serialized_start=422
  _GROUPPOLICY._serialized_end=538
  _GROUP._serialized_start=541
  _GROUP._serialized_end=720
  _INSTANCEPROFILE._serialized_start=723
  _INSTANCEPROFILE._serialized_end=857
  _MANAGEDPOLICY._serialized_start=860
  _MANAGEDPOLICY._serialized_end=1067
  _POLICY._serialized_start=1070
  _POLICY._serialized_end=1227
  _ROLEPOLICY._serialized_start=1229
  _ROLEPOLICY._serialized_end=1344
  _ROLE._serialized_start=1347
  _ROLE._serialized_end=1737
  _ROLE_TAGSENTRY._serialized_start=1694
  _ROLE_TAGSENTRY._serialized_end=1737
  _SERVICELINKEDROLE._serialized_start=1740
  _SERVICELINKEDROLE._serialized_end=1886
  _USERLOGINPROFILE._serialized_start=1888
  _USERLOGINPROFILE._serialized_end=2014
  _USERPOLICY._serialized_start=2016
  _USERPOLICY._serialized_end=2131
  _USER._serialized_start=2134
  _USER._serialized_end=2514
  _USER_TAGSENTRY._serialized_start=1694
  _USER_TAGSENTRY._serialized_end=1737
  _USERTOGROUPADDITION._serialized_start=2516
  _USERTOGROUPADDITION._serialized_end=2629
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_athena.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61ws/aws_athena.proto\x12\x16oak9.tython.aws.athena\x1a\x13shared/shared.proto\"\xb8\x01\n\x0f\x44\x61taCatalogTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12?\n\x04tags\x18\x02 \x03(\x0b\x32\x31.oak9.tython.aws.athena.DataCatalogTags.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xaa\x02\n\x0b\x44\x61taCatalog\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12G\n\nparameters\x18\x04 \x03(\x0b\x32\x33.oak9.tython.aws.athena.DataCatalog.ParametersEntry\x12\x35\n\x04tags\x18\x05 \x01(\x0b\x32\'.oak9.tython.aws.athena.DataCatalogTags\x12\x0c\n\x04type\x18\x06 \x01(\t\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb3\x01\n\x06\x41thena\x12\x39\n\x0c\x64\x61ta_catalog\x18\x01 \x03(\x0b\x32#.oak9.tython.aws.athena.DataCatalog\x12\x37\n\x0bnamed_query\x18\x02 \x03(\x0b\x32\".oak9.tython.aws.athena.NamedQuery\x12\x35\n\nwork_group\x18\x03 \x03(\x0b\x32!.oak9.tython.aws.athena.WorkGroup\"\x90\x01\n\nNamedQuery\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x14\n\x0cquery_string\x18\x05 \x01(\t\"\xb4\x01\n\rWorkGroupTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\x04tags\x18\x02 \x03(\x0b\x32/.oak9.tython.aws.athena.WorkGroupTags.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x87\x01\n WorkGroupEncryptionConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x65ncryption_option\x18\x02 \x01(\t\x12\x0f\n\x07kms_key\x18\x03 \x01(\t\"\xcc\x01\n\x1cWorkGroupResultConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Z\n\x18\x65ncryption_configuration\x18\x02 \x01(\x0b\x32\x38.oak9.tython.aws.athena.WorkGroupEncryptionConfiguration\x12\x17\n\x0foutput_location\x18\x03 \x01(\t\"\xcd\x02\n\x1fWorkGroupWorkGroupConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1e\x62ytes_scanned_cutoff_per_query\x18\x02 \x01(\x05\x12(\n enforce_work_group_configuration\x18\x03 \x01(\x08\x12+\n#publish_cloud_watch_metrics_enabled\x18\x04 \x01(\x08\x12\x1e\n\x16requester_pays_enabled\x18\x05 \x01(\x08\x12R\n\x14result_configuration\x18\x06 \x01(\x0b\x32\x34.oak9.tython.aws.athena.WorkGroupResultConfiguration\"\x9c\x02\n#WorkGroupResultConfigurationUpdates\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Z\n\x18\x65ncryption_configuration\x18\x02 \x01(\x0b\x32\x38.oak9.tython.aws.athena.WorkGroupEncryptionConfiguration\x12\x17\n\x0foutput_location\x18\x03 \x01(\t\x12\'\n\x1fremove_encryption_configuration\x18\x04 \x01(\x08\x12\x1e\n\x16remove_output_location\x18\x05 \x01(\x08\"\x92\x03\n&WorkGroupWorkGroupConfigurationUpdates\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1e\x62ytes_scanned_cutoff_per_query\x18\x02 \x01(\x05\x12(\n enforce_work_group_configuration\x18\x03 \x01(\x08\x12+\n#publish_cloud_watch_metrics_enabled\x18\x04 \x01(\x08\x12\x1e\n\x16requester_pays_enabled\x18\x05 \x01(\x08\x12\x61\n\x1cresult_configuration_updates\x18\x06 \x01(\x0b\x32;.oak9.tython.aws.athena.WorkGroupResultConfigurationUpdates\x12-\n%remove_bytes_scanned_cutoff_per_query\x18\x07 \x01(\x08\"\x91\x03\n\tWorkGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x33\n\x04tags\x18\x04 \x01(\x0b\x32%.oak9.tython.aws.athena.WorkGroupTags\x12Y\n\x18work_group_configuration\x18\x05 \x01(\x0b\x32\x37.oak9.tython.aws.athena.WorkGroupWorkGroupConfiguration\x12h\n work_group_configuration_updates\x18\x06 \x01(\x0b\x32>.oak9.tython.aws.athena.WorkGroupWorkGroupConfigurationUpdates\x12\r\n\x05state\x18\x07 \x01(\t\x12\x1f\n\x17recursive_delete_option\x18\x08 \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_athena_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DATACATALOGTAGS_TAGSENTRY._options = None
  _DATACATALOGTAGS_TAGSENTRY._serialized_options = b'8\001'
  _DATACATALOG_PARAMETERSENTRY._options = None
  _DATACATALOG_PARAMETERSENTRY._serialized_options = b'8\001'
  _WORKGROUPTAGS_TAGSENTRY._options = None
  _WORKGROUPTAGS_TAGSENTRY._serialized_options = b'8\001'
  _DATACATALOGTAGS._serialized_start=70
  _DATACATALOGTAGS._serialized_end=254
  _DATACATALOGTAGS_TAGSENTRY._serialized_start=211
  _DATACATALOGTAGS_TAGSENTRY._serialized_end=254
  _DATACATALOG._serialized_start=257
  _DATACATALOG._serialized_end=555
  _DATACATALOG_PARAMETERSENTRY._serialized_start=506
  _DATACATALOG_PARAMETERSENTRY._serialized_end=555
  _ATHENA._serialized_start=558
  _ATHENA._serialized_end=737
  _NAMEDQUERY._serialized_start=740
  _NAMEDQUERY._serialized_end=884
  _WORKGROUPTAGS._serialized_start=887
  _WORKGROUPTAGS._serialized_end=1067
  _WORKGROUPTAGS_TAGSENTRY._serialized_start=211
  _WORKGROUPTAGS_TAGSENTRY._serialized_end=254
  _WORKGROUPENCRYPTIONCONFIGURATION._serialized_start=1070
  _WORKGROUPENCRYPTIONCONFIGURATION._serialized_end=1205
  _WORKGROUPRESULTCONFIGURATION._serialized_start=1208
  _WORKGROUPRESULTCONFIGURATION._serialized_end=1412
  _WORKGROUPWORKGROUPCONFIGURATION._serialized_start=1415
  _WORKGROUPWORKGROUPCONFIGURATION._serialized_end=1748
  _WORKGROUPRESULTCONFIGURATIONUPDATES._serialized_start=1751
  _WORKGROUPRESULTCONFIGURATIONUPDATES._serialized_end=2035
  _WORKGROUPWORKGROUPCONFIGURATIONUPDATES._serialized_start=2038
  _WORKGROUPWORKGROUPCONFIGURATIONUPDATES._serialized_end=2440
  _WORKGROUP._serialized_start=2443
  _WORKGROUP._serialized_end=2844
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ProjectVpcConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SUBNETS_FIELD_NUMBER: builtins.int
    VPC_ID_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def subnets(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    vpc_id: builtins.str
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        subnets: collections.abc.Iterable[builtins.str] | None = ...,
        vpc_id: builtins.str = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "security_group_ids", b"security_group_ids", "subnets", b"subnets", "vpc_id", b"vpc_id"]) -> None: ...

global___ProjectVpcConfig = ProjectVpcConfig

@typing_extensions.final
class ProjectSourceAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    resource: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource", b"resource", "resource_info", b"resource_info"]) -> None: ...

global___ProjectSourceAuth = ProjectSourceAuth

@typing_extensions.final
class ProjectBuildStatusConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTEXT_FIELD_NUMBER: builtins.int
    TARGET_URL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    context: builtins.str
    target_url: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        context: builtins.str = ...,
        target_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["context", b"context", "resource_info", b"resource_info", "target_url", b"target_url"]) -> None: ...

global___ProjectBuildStatusConfig = ProjectBuildStatusConfig

@typing_extensions.final
class ProjectGitSubmodulesConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FETCH_SUBMODULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    fetch_submodules: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        fetch_submodules: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fetch_submodules", b"fetch_submodules", "resource_info", b"resource_info"]) -> None: ...

global___ProjectGitSubmodulesConfig = ProjectGitSubmodulesConfig

@typing_extensions.final
class ProjectSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REPORT_BUILD_STATUS_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    SOURCE_IDENTIFIER_FIELD_NUMBER: builtins.int
    BUILD_SPEC_FIELD_NUMBER: builtins.int
    GIT_CLONE_DEPTH_FIELD_NUMBER: builtins.int
    BUILD_STATUS_CONFIG_FIELD_NUMBER: builtins.int
    GIT_SUBMODULES_CONFIG_FIELD_NUMBER: builtins.int
    INSECURE_SSL_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    report_build_status: builtins.bool
    @property
    def auth(self) -> global___ProjectSourceAuth: ...
    source_identifier: builtins.str
    build_spec: builtins.str
    git_clone_depth: builtins.int
    @property
    def build_status_config(self) -> global___ProjectBuildStatusConfig: ...
    @property
    def git_submodules_config(self) -> global___ProjectGitSubmodulesConfig: ...
    insecure_ssl: builtins.bool
    location: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        report_build_status: builtins.bool = ...,
        auth: global___ProjectSourceAuth | None = ...,
        source_identifier: builtins.str = ...,
        build_spec: builtins.str = ...,
        git_clone_depth: builtins.int = ...,
        build_status_config: global___ProjectBuildStatusConfig | None = ...,
        git_submodules_config: global___ProjectGitSubmodulesConfig | None = ...,
        insecure_ssl: builtins.bool = ...,
        location: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "build_status_config", b"build_status_config", "git_submodules_config", b"git_submodules_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "build_spec", b"build_spec", "build_status_config", b"build_status_config", "git_clone_depth", b"git_clone_depth", "git_submodules_config", b"git_submodules_config", "insecure_ssl", b"insecure_ssl", "location", b"location", "report_build_status", b"report_build_status", "resource_info", b"resource_info", "source_identifier", b"source_identifier"]) -> None: ...

global___ProjectSource = ProjectSource

@typing_extensions.final
class ProjectFilterGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___ProjectFilterGroup = ProjectFilterGroup

@typing_extensions.final
class ProjectProjectTriggers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FILTER_GROUPS_FIELD_NUMBER: builtins.int
    WEBHOOK_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def filter_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProjectFilterGroup]: ...
    webhook: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        filter_groups: collections.abc.Iterable[global___ProjectFilterGroup] | None = ...,
        webhook: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["filter_groups", b"filter_groups", "resource_info", b"resource_info", "webhook", b"webhook"]) -> None: ...

global___ProjectProjectTriggers = ProjectProjectTriggers

@typing_extensions.final
class ProjectArtifacts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    ARTIFACT_IDENTIFIER_FIELD_NUMBER: builtins.int
    OVERRIDE_ARTIFACT_NAME_FIELD_NUMBER: builtins.int
    PACKAGING_FIELD_NUMBER: builtins.int
    ENCRYPTION_DISABLED_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    path: builtins.str
    artifact_identifier: builtins.str
    override_artifact_name: builtins.bool
    packaging: builtins.str
    encryption_disabled: builtins.bool
    location: builtins.str
    name: builtins.str
    namespace_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        path: builtins.str = ...,
        artifact_identifier: builtins.str = ...,
        override_artifact_name: builtins.bool = ...,
        packaging: builtins.str = ...,
        encryption_disabled: builtins.bool = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        namespace_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifact_identifier", b"artifact_identifier", "encryption_disabled", b"encryption_disabled", "location", b"location", "name", b"name", "namespace_type", b"namespace_type", "override_artifact_name", b"override_artifact_name", "packaging", b"packaging", "path", b"path", "resource_info", b"resource_info"]) -> None: ...

global___ProjectArtifacts = ProjectArtifacts

@typing_extensions.final
class ProjectCloudWatchLogsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    GROUP_NAME_FIELD_NUMBER: builtins.int
    STREAM_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    status: builtins.str
    group_name: builtins.str
    stream_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        status: builtins.str = ...,
        group_name: builtins.str = ...,
        stream_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_name", b"group_name", "resource_info", b"resource_info", "status", b"status", "stream_name", b"stream_name"]) -> None: ...

global___ProjectCloudWatchLogsConfig = ProjectCloudWatchLogsConfig

@typing_extensions.final
class ProjectS3LogsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ENCRYPTION_DISABLED_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    status: builtins.str
    encryption_disabled: builtins.bool
    location: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        status: builtins.str = ...,
        encryption_disabled: builtins.bool = ...,
        location: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["encryption_disabled", b"encryption_disabled", "location", b"location", "resource_info", b"resource_info", "status", b"status"]) -> None: ...

global___ProjectS3LogsConfig = ProjectS3LogsConfig

@typing_extensions.final
class ProjectLogsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_LOGS_FIELD_NUMBER: builtins.int
    S3_LOGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def cloud_watch_logs(self) -> global___ProjectCloudWatchLogsConfig: ...
    @property
    def s3_logs(self) -> global___ProjectS3LogsConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cloud_watch_logs: global___ProjectCloudWatchLogsConfig | None = ...,
        s3_logs: global___ProjectS3LogsConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_watch_logs", b"cloud_watch_logs", "resource_info", b"resource_info", "s3_logs", b"s3_logs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_watch_logs", b"cloud_watch_logs", "resource_info", b"resource_info", "s3_logs", b"s3_logs"]) -> None: ...

global___ProjectLogsConfig = ProjectLogsConfig

@typing_extensions.final
class ProjectProjectFileSystemLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MOUNT_POINT_FIELD_NUMBER: builtins.int
    IDENTIFIER_FIELD_NUMBER: builtins.int
    MOUNT_OPTIONS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    mount_point: builtins.str
    identifier: builtins.str
    mount_options: builtins.str
    location: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        mount_point: builtins.str = ...,
        identifier: builtins.str = ...,
        mount_options: builtins.str = ...,
        location: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "location", b"location", "mount_options", b"mount_options", "mount_point", b"mount_point", "resource_info", b"resource_info"]) -> None: ...

global___ProjectProjectFileSystemLocation = ProjectProjectFileSystemLocation

@typing_extensions.final
class ProjectEnvironmentVariable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___ProjectEnvironmentVariable = ProjectEnvironmentVariable

@typing_extensions.final
class ProjectRegistryCredential(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CREDENTIAL_FIELD_NUMBER: builtins.int
    CREDENTIAL_PROVIDER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    credential: builtins.str
    credential_provider: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        credential: builtins.str = ...,
        credential_provider: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["credential", b"credential", "credential_provider", b"credential_provider", "resource_info", b"resource_info"]) -> None: ...

global___ProjectRegistryCredential = ProjectRegistryCredential

@typing_extensions.final
class ProjectEnvironment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENVIRONMENT_VARIABLES_FIELD_NUMBER: builtins.int
    PRIVILEGED_MODE_FIELD_NUMBER: builtins.int
    IMAGE_PULL_CREDENTIALS_TYPE_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    REGISTRY_CREDENTIAL_FIELD_NUMBER: builtins.int
    COMPUTE_TYPE_FIELD_NUMBER: builtins.int
    CERTIFICATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def environment_variables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProjectEnvironmentVariable]: ...
    privileged_mode: builtins.bool
    image_pull_credentials_type: builtins.str
    image: builtins.str
    @property
    def registry_credential(self) -> global___ProjectRegistryCredential: ...
    compute_type: builtins.str
    certificate: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        environment_variables: collections.abc.Iterable[global___ProjectEnvironmentVariable] | None = ...,
        privileged_mode: builtins.bool = ...,
        image_pull_credentials_type: builtins.str = ...,
        image: builtins.str = ...,
        registry_credential: global___ProjectRegistryCredential | None = ...,
        compute_type: builtins.str = ...,
        certificate: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["registry_credential", b"registry_credential", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate", b"certificate", "compute_type", b"compute_type", "environment_variables", b"environment_variables", "image", b"image", "image_pull_credentials_type", b"image_pull_credentials_type", "privileged_mode", b"privileged_mode", "registry_credential", b"registry_credential", "resource_info", b"resource_info"]) -> None: ...

global___ProjectEnvironment = ProjectEnvironment

@typing_extensions.final
class ProjectProjectSourceVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SOURCE_IDENTIFIER_FIELD_NUMBER: builtins.int
    SOURCE_VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    source_identifier: builtins.str
    source_version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        source_identifier: builtins.str = ...,
        source_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "source_identifier", b"source_identifier", "source_version", b"source_version"]) -> None: ...

global___ProjectProjectSourceVersion = ProjectProjectSourceVersion

@typing_extensions.final
class ProjectBatchRestrictions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMPUTE_TYPES_ALLOWED_FIELD_NUMBER: builtins.int
    MAXIMUM_BUILDS_ALLOWED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def compute_types_allowed(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    maximum_builds_allowed: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        compute_types_allowed: collections.abc.Iterable[builtins.str] | None = ...,
        maximum_builds_allowed: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_types_allowed", b"compute_types_allowed", "maximum_builds_allowed", b"maximum_builds_allowed", "resource_info", b"resource_info"]) -> None: ...

global___ProjectBatchRestrictions = ProjectBatchRestrictions

@typing_extensions.final
class ProjectProjectBuildBatchConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMBINE_ARTIFACTS_FIELD_NUMBER: builtins.int
    SERVICE_ROLE_FIELD_NUMBER: builtins.int
    TIMEOUT_IN_MINS_FIELD_NUMBER: builtins.int
    RESTRICTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    combine_artifacts: builtins.bool
    service_role: builtins.str
    timeout_in_mins: builtins.int
    @property
    def restrictions(self) -> global___ProjectBatchRestrictions: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        combine_artifacts: builtins.bool = ...,
        service_role: builtins.str = ...,
        timeout_in_mins: builtins.int = ...,
        restrictions: global___ProjectBatchRestrictions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "restrictions", b"restrictions"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["combine_artifacts", b"combine_artifacts", "resource_info", b"resource_info", "restrictions", b"restrictions", "service_role", b"service_role", "timeout_in_mins", b"timeout_in_mins"]) -> None: ...

global___ProjectProjectBuildBatchConfig = ProjectProjectBuildBatchConfig

@typing_extensions.final
class ProjectProjectCache(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MODES_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def modes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    location: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        modes: collections.abc.Iterable[builtins.str] | None = ...,
        location: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "modes", b"modes", "resource_info", b"resource_info"]) -> None: ...

global___ProjectProjectCache = ProjectProjectCache

@typing_extensions.final
class Project(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    VPC_CONFIG_FIELD_NUMBER: builtins.int
    SECONDARY_SOURCES_FIELD_NUMBER: builtins.int
    ENCRYPTION_KEY_FIELD_NUMBER: builtins.int
    SOURCE_VERSION_FIELD_NUMBER: builtins.int
    TRIGGERS_FIELD_NUMBER: builtins.int
    SECONDARY_ARTIFACTS_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ARTIFACTS_FIELD_NUMBER: builtins.int
    BADGE_ENABLED_FIELD_NUMBER: builtins.int
    LOGS_CONFIG_FIELD_NUMBER: builtins.int
    SERVICE_ROLE_FIELD_NUMBER: builtins.int
    QUEUED_TIMEOUT_IN_MINUTES_FIELD_NUMBER: builtins.int
    FILE_SYSTEM_LOCATIONS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    SECONDARY_SOURCE_VERSIONS_FIELD_NUMBER: builtins.int
    BUILD_BATCH_CONFIG_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TIMEOUT_IN_MINUTES_FIELD_NUMBER: builtins.int
    CACHE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def vpc_config(self) -> global___ProjectVpcConfig: ...
    @property
    def secondary_sources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProjectSource]: ...
    encryption_key: builtins.str
    source_version: builtins.str
    @property
    def triggers(self) -> global___ProjectProjectTriggers: ...
    @property
    def secondary_artifacts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProjectArtifacts]: ...
    @property
    def source(self) -> global___ProjectSource: ...
    name: builtins.str
    @property
    def artifacts(self) -> global___ProjectArtifacts: ...
    badge_enabled: builtins.bool
    @property
    def logs_config(self) -> global___ProjectLogsConfig: ...
    service_role: builtins.str
    queued_timeout_in_minutes: builtins.int
    @property
    def file_system_locations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProjectProjectFileSystemLocation]: ...
    @property
    def environment(self) -> global___ProjectEnvironment: ...
    @property
    def secondary_source_versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProjectProjectSourceVersion]: ...
    @property
    def build_batch_config(self) -> global___ProjectProjectBuildBatchConfig: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    timeout_in_minutes: builtins.int
    @property
    def cache(self) -> global___ProjectProjectCache: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        vpc_config: global___ProjectVpcConfig | None = ...,
        secondary_sources: collections.abc.Iterable[global___ProjectSource] | None = ...,
        encryption_key: builtins.str = ...,
        source_version: builtins.str = ...,
        triggers: global___ProjectProjectTriggers | None = ...,
        secondary_artifacts: collections.abc.Iterable[global___ProjectArtifacts] | None = ...,
        source: global___ProjectSource | None = ...,
        name: builtins.str = ...,
        artifacts: global___ProjectArtifacts | None = ...,
        badge_enabled: builtins.bool = ...,
        logs_config: global___ProjectLogsConfig | None = ...,
        service_role: builtins.str = ...,
        queued_timeout_in_minutes: builtins.int = ...,
        file_system_locations: collections.abc.Iterable[global___ProjectProjectFileSystemLocation] | None = ...,
        environment: global___ProjectEnvironment | None = ...,
        secondary_source_versions: collections.abc.Iterable[global___ProjectProjectSourceVersion] | None = ...,
        build_batch_config: global___ProjectProjectBuildBatchConfig | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        timeout_in_minutes: builtins.int = ...,
        cache: global___ProjectProjectCache | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["artifacts", b"artifacts", "build_batch_config", b"build_batch_config", "cache", b"cache", "environment", b"environment", "logs_config", b"logs_config", "resource_info", b"resource_info", "source", b"source", "triggers", b"triggers", "vpc_config", b"vpc_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifacts", b"artifacts", "badge_enabled", b"badge_enabled", "build_batch_config", b"build_batch_config", "cache", b"cache", "description", b"description", "encryption_key", b"encryption_key", "environment", b"environment", "file_system_locations", b"file_system_locations", "logs_config", b"logs_config", "name", b"name", "queued_timeout_in_minutes", b"queued_timeout_in_minutes", "resource_info", b"resource_info", "secondary_artifacts", b"secondary_artifacts", "secondary_source_versions", b"secondary_source_versions", "secondary_sources", b"secondary_sources", "service_role", b"service_role", "source", b"source", "source_version", b"source_version", "tags", b"tags", "timeout_in_minutes", b"timeout_in_minutes", "triggers", b"triggers", "vpc_config", b"vpc_config"]) -> None: ...

global___Project = Project

@typing_extensions.final
class CodeBuild(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_FIELD_NUMBER: builtins.int
    REPORT_GROUP_FIELD_NUMBER: builtins.int
    SOURCE_CREDENTIAL_FIELD_NUMBER: builtins.int
    PROJECT_WEBHOOK_FILTER_FIELD_NUMBER: builtins.int
    @property
    def project(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Project]: ...
    @property
    def report_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReportGroup]: ...
    @property
    def source_credential(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SourceCredential]: ...
    @property
    def project_webhook_filter(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProjectWebhookFilter]: ...
    def __init__(
        self,
        *,
        project: collections.abc.Iterable[global___Project] | None = ...,
        report_group: collections.abc.Iterable[global___ReportGroup] | None = ...,
        source_credential: collections.abc.Iterable[global___SourceCredential] | None = ...,
        project_webhook_filter: collections.abc.Iterable[global___ProjectWebhookFilter] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["project", b"project", "project_webhook_filter", b"project_webhook_filter", "report_group", b"report_group", "source_credential", b"source_credential"]) -> None: ...

global___CodeBuild = CodeBuild

@typing_extensions.final
class ReportGroupS3ReportExportConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    PACKAGING_FIELD_NUMBER: builtins.int
    ENCRYPTION_KEY_FIELD_NUMBER: builtins.int
    ENCRYPTION_DISABLED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    path: builtins.str
    bucket: builtins.str
    packaging: builtins.str
    encryption_key: builtins.str
    encryption_disabled: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        path: builtins.str = ...,
        bucket: builtins.str = ...,
        packaging: builtins.str = ...,
        encryption_key: builtins.str = ...,
        encryption_disabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "encryption_disabled", b"encryption_disabled", "encryption_key", b"encryption_key", "packaging", b"packaging", "path", b"path", "resource_info", b"resource_info"]) -> None: ...

global___ReportGroupS3ReportExportConfig = ReportGroupS3ReportExportConfig

@typing_extensions.final
class ReportGroupReportExportConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_DESTINATION_FIELD_NUMBER: builtins.int
    EXPORT_CONFIG_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def s3_destination(self) -> global___ReportGroupS3ReportExportConfig: ...
    export_config_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_destination: global___ReportGroupS3ReportExportConfig | None = ...,
        export_config_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_destination", b"s3_destination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["export_config_type", b"export_config_type", "resource_info", b"resource_info", "s3_destination", b"s3_destination"]) -> None: ...

global___ReportGroupReportExportConfig = ReportGroupReportExportConfig

@typing_extensions.final
class ReportGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    EXPORT_CONFIG_FIELD_NUMBER: builtins.int
    DELETE_REPORTS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    type: builtins.str
    @property
    def export_config(self) -> global___ReportGroupReportExportConfig: ...
    delete_reports: builtins.bool
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        type: builtins.str = ...,
        export_config: global___ReportGroupReportExportConfig | None = ...,
        delete_reports: builtins.bool = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["export_config", b"export_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete_reports", b"delete_reports", "export_config", b"export_config", "name", b"name", "resource_info", b"resource_info", "tags", b"tags", "type", b"type"]) -> None: ...

global___ReportGroup = ReportGroup

@typing_extensions.final
class SourceCredential(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SERVER_TYPE_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    AUTH_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    server_type: builtins.str
    username: builtins.str
    token: builtins.str
    auth_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        server_type: builtins.str = ...,
        username: builtins.str = ...,
        token: builtins.str = ...,
        auth_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_type", b"auth_type", "resource_info", b"resource_info", "server_type", b"server_type", "token", b"token", "username", b"username"]) -> None: ...

global___SourceCredential = SourceCredential

@typing_extensions.final
class ProjectWebhookFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PATTERN_FIELD_NUMBER: builtins.int
    EXCLUDE_MATCHED_PATTERN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    pattern: builtins.str
    exclude_matched_pattern: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        pattern: builtins.str = ...,
        exclude_matched_pattern: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["exclude_matched_pattern", b"exclude_matched_pattern", "pattern", b"pattern", "resource_info", b"resource_info"]) -> None: ...

global___ProjectWebhookFilter = ProjectWebhookFilter



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_per.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19gcp/gcp_compute_per.proto\x12\x1boak9.tython.gcp.compute_per\x1a\x13shared/shared.proto\"v\n,ComputePerInstanceConfigXPreservedStateXDisk\x12\x13\n\x0b\x64\x65lete_rule\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x0c\n\x04mode\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\"\x99\x02\n\'ComputePerInstanceConfigXPreservedState\x12\x64\n\x08metadata\x18\x01 \x03(\x0b\x32R.oak9.tython.gcp.compute_per.ComputePerInstanceConfigXPreservedState.MetadataEntry\x12W\n\x04\x64isk\x18\x02 \x03(\x0b\x32I.oak9.tython.gcp.compute_per.ComputePerInstanceConfigXPreservedStateXDisk\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"S\n!ComputePerInstanceConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc7\x03\n\x18\x43omputePerInstanceConfig\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1e\n\x16instance_group_manager\x18\x02 \x01(\t\x12\x16\n\x0eminimal_action\x18\x03 \x01(\t\x12&\n\x1emost_disruptive_allowed_action\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12(\n remove_instance_state_on_destroy\x18\x07 \x01(\x08\x12\x0c\n\x04zone\x18\x08 \x01(\t\x12]\n\x0fpreserved_state\x18\t \x01(\x0b\x32\x44.oak9.tython.gcp.compute_per.ComputePerInstanceConfigXPreservedState\x12P\n\x08timeouts\x18\n \x01(\x0b\x32>.oak9.tython.gcp.compute_per.ComputePerInstanceConfigXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_per_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEPERINSTANCECONFIGXPRESERVEDSTATE_METADATAENTRY._options = None
  _COMPUTEPERINSTANCECONFIGXPRESERVEDSTATE_METADATAENTRY._serialized_options = b'8\001'
  _COMPUTEPERINSTANCECONFIGXPRESERVEDSTATEXDISK._serialized_start=79
  _COMPUTEPERINSTANCECONFIGXPRESERVEDSTATEXDISK._serialized_end=197
  _COMPUTEPERINSTANCECONFIGXPRESERVEDSTATE._serialized_start=200
  _COMPUTEPERINSTANCECONFIGXPRESERVEDSTATE._serialized_end=481
  _COMPUTEPERINSTANCECONFIGXPRESERVEDSTATE_METADATAENTRY._serialized_start=434
  _COMPUTEPERINSTANCECONFIGXPRESERVEDSTATE_METADATAENTRY._serialized_end=481
  _COMPUTEPERINSTANCECONFIGXTIMEOUTS._serialized_start=483
  _COMPUTEPERINSTANCECONFIGXTIMEOUTS._serialized_end=566
  _COMPUTEPERINSTANCECONFIG._serialized_start=569
  _COMPUTEPERINSTANCECONFIG._serialized_end=1024
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.api.core.v1_pb2
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AllocationResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AVAILABLE_ON_NODES_FIELD_NUMBER: builtins.int
    RESOURCE_HANDLE_FIELD_NUMBER: builtins.int
    SHAREABLE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def available_on_nodes(self) -> kubernetes.kubernetes_io.k8s.api.core.v1_pb2.NodeSelector: ...
    resource_handle: builtins.str
    shareable: builtins.bool
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        available_on_nodes: kubernetes.kubernetes_io.k8s.api.core.v1_pb2.NodeSelector | None = ...,
        resource_handle: builtins.str = ...,
        shareable: builtins.bool = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["available_on_nodes", b"available_on_nodes", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["available_on_nodes", b"available_on_nodes", "resource_handle", b"resource_handle", "resource_info", b"resource_info", "shareable", b"shareable"]) -> None: ...

global___AllocationResult = AllocationResult

@typing_extensions.final
class PodScheduling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___PodSchedulingSpec: ...
    @property
    def status(self) -> global___PodSchedulingStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___PodSchedulingSpec | None = ...,
        status: global___PodSchedulingStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___PodScheduling = PodScheduling

@typing_extensions.final
class PodSchedulingList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PodScheduling]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___PodScheduling] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___PodSchedulingList = PodSchedulingList

@typing_extensions.final
class PodSchedulingSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POTENTIAL_NODES_FIELD_NUMBER: builtins.int
    SELECTED_NODE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def potential_nodes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    selected_node: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        potential_nodes: collections.abc.Iterable[builtins.str] | None = ...,
        selected_node: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["potential_nodes", b"potential_nodes", "resource_info", b"resource_info", "selected_node", b"selected_node"]) -> None: ...

global___PodSchedulingSpec = PodSchedulingSpec

@typing_extensions.final
class PodSchedulingStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_CLAIMS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_claims(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceClaimSchedulingStatus]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_claims: collections.abc.Iterable[global___ResourceClaimSchedulingStatus] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_claims", b"resource_claims", "resource_info", b"resource_info"]) -> None: ...

global___PodSchedulingStatus = PodSchedulingStatus

@typing_extensions.final
class ResourceClaim(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___ResourceClaimSpec: ...
    @property
    def status(self) -> global___ResourceClaimStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___ResourceClaimSpec | None = ...,
        status: global___ResourceClaimStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___ResourceClaim = ResourceClaim

@typing_extensions.final
class ResourceClaimConsumerReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GROUP_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_group: builtins.str
    name: builtins.str
    resource: builtins.str
    uid: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_group: builtins.str = ...,
        name: builtins.str = ...,
        resource: builtins.str = ...,
        uid: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_group", b"api_group", "name", b"name", "resource", b"resource", "resource_info", b"resource_info", "uid", b"uid"]) -> None: ...

global___ResourceClaimConsumerReference = ResourceClaimConsumerReference

@typing_extensions.final
class ResourceClaimList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceClaim]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___ResourceClaim] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___ResourceClaimList = ResourceClaimList

@typing_extensions.final
class ResourceClaimParametersReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GROUP_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_group: builtins.str
    kind: builtins.str
    name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_group: builtins.str = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_group", b"api_group", "kind", b"kind", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ResourceClaimParametersReference = ResourceClaimParametersReference

@typing_extensions.final
class ResourceClaimSchedulingStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    UNSUITABLE_NODES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def unsuitable_nodes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        unsuitable_nodes: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "unsuitable_nodes", b"unsuitable_nodes"]) -> None: ...

global___ResourceClaimSchedulingStatus = ResourceClaimSchedulingStatus

@typing_extensions.final
class ResourceClaimSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOCATION_MODE_FIELD_NUMBER: builtins.int
    PARAMETERS_REF_FIELD_NUMBER: builtins.int
    RESOURCE_CLASS_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    allocation_mode: builtins.str
    @property
    def parameters_ref(self) -> global___ResourceClaimParametersReference: ...
    resource_class_name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        allocation_mode: builtins.str = ...,
        parameters_ref: global___ResourceClaimParametersReference | None = ...,
        resource_class_name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["parameters_ref", b"parameters_ref", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allocation_mode", b"allocation_mode", "parameters_ref", b"parameters_ref", "resource_class_name", b"resource_class_name", "resource_info", b"resource_info"]) -> None: ...

global___ResourceClaimSpec = ResourceClaimSpec

@typing_extensions.final
class ResourceClaimStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOCATION_FIELD_NUMBER: builtins.int
    DEALLOCATION_REQUESTED_FIELD_NUMBER: builtins.int
    DRIVER_NAME_FIELD_NUMBER: builtins.int
    RESERVED_FOR_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def allocation(self) -> global___AllocationResult: ...
    deallocation_requested: builtins.bool
    driver_name: builtins.str
    @property
    def reserved_for(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceClaimConsumerReference]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        allocation: global___AllocationResult | None = ...,
        deallocation_requested: builtins.bool = ...,
        driver_name: builtins.str = ...,
        reserved_for: collections.abc.Iterable[global___ResourceClaimConsumerReference] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["allocation", b"allocation", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allocation", b"allocation", "deallocation_requested", b"deallocation_requested", "driver_name", b"driver_name", "reserved_for", b"reserved_for", "resource_info", b"resource_info"]) -> None: ...

global___ResourceClaimStatus = ResourceClaimStatus

@typing_extensions.final
class ResourceClaimTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___ResourceClaimTemplateSpec: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___ResourceClaimTemplateSpec | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> None: ...

global___ResourceClaimTemplate = ResourceClaimTemplate

@typing_extensions.final
class ResourceClaimTemplateList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceClaimTemplate]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___ResourceClaimTemplate] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___ResourceClaimTemplateList = ResourceClaimTemplateList

@typing_extensions.final
class ResourceClaimTemplateSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___ResourceClaimSpec: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___ResourceClaimSpec | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> None: ...

global___ResourceClaimTemplateSpec = ResourceClaimTemplateSpec

@typing_extensions.final
class ResourceClass(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    DRIVER_NAME_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    PARAMETERS_REF_FIELD_NUMBER: builtins.int
    SUITABLE_NODES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    driver_name: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def parameters_ref(self) -> global___ResourceClassParametersReference: ...
    @property
    def suitable_nodes(self) -> kubernetes.kubernetes_io.k8s.api.core.v1_pb2.NodeSelector: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        driver_name: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        parameters_ref: global___ResourceClassParametersReference | None = ...,
        suitable_nodes: kubernetes.kubernetes_io.k8s.api.core.v1_pb2.NodeSelector | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "parameters_ref", b"parameters_ref", "resource_info", b"resource_info", "suitable_nodes", b"suitable_nodes"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "driver_name", b"driver_name", "kind", b"kind", "metadata", b"metadata", "parameters_ref", b"parameters_ref", "resource_info", b"resource_info", "suitable_nodes", b"suitable_nodes"]) -> None: ...

global___ResourceClass = ResourceClass

@typing_extensions.final
class ResourceClassList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceClass]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___ResourceClass] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___ResourceClassList = ResourceClassList

@typing_extensions.final
class ResourceClassParametersReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GROUP_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_group: builtins.str
    kind: builtins.str
    name: builtins.str
    namespace: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_group: builtins.str = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        namespace: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_group", b"api_group", "kind", b"kind", "name", b"name", "namespace", b"namespace", "resource_info", b"resource_info"]) -> None: ...

global___ResourceClassParametersReference = ResourceClassParametersReference
